.\" -*- nroff -*- generated from .Rd format
.BG
.FN likfit
.TL
Likelihood Estimation for Gaussian Random Fields
.DN
Parameter estimation for (transformed) Gaussian
random fields by maximum likelihood (ML) or
restricted maximum likelihood (REML).
.CS

likfit(geodata, coords = geodata$coords, data = geodata$data,
       trend = "cte", ini.cov.pars, fix.nugget = FALSE, nugget = 0,
       fix.kappa = TRUE, kappa = 0.5, fix.lambda = TRUE, lambda = 1,
       fix.psiA = TRUE, psiA = 0, fix.psiR = TRUE, psiR = 1, 
       cov.model = c("matern", "exponential", "gaussian",
                     "spherical", "circular","cubic", "wave",
                     "powered.exponential", "cauchy", "gneiting",
                     "gneiting.matern", "pure.nugget"),
       method = "ML", components = FALSE, nospatial = TRUE,
       limits = likfit.limits(), messages.screen = TRUE, ...)

.RA
.AG geodata
a list containing elements `coords' and
`data' as described next. 
Typically an object of the class `"geodata"' - a geoR
data-set.
If not provided the arguments
`coords' and `data' must be provided instead.  
.AG coords
an n x 2 matrix, each row containing Euclidean
coordinates of the n data locations. By default it takes the
element `$coords' of the argument `geodata'.  
.AG data
a vector with data values. By default it takes the
element `$data' of the argument `geodata'.  
.AG trend
specifies the mean part of the model. The options are:
`"cte"' (constant mean),
`"1st"' (a first degree polynomial
on the coordinates), `"2nd"' (a second degree polynomial
on the coordinates), or a formula of the type `~X' where `X'
is a matrix with the covariates (external trend). Defauts to `"cte"'.  
.AG ini.cov.pars
initial values for the covariance parameters:
sigma^2 (partial sill) and phi (range
parameter).  
.AG fix.nugget
logical, indicating whether the parameter
tau^2 (nugget variance) should be regarded as fixed
(`fix.nugget = TRUE') or is
to be estimated (`fix.nugget = FALSE'). Defaults to
`FALSE'.  
.AG nugget
value for the nugget parameter.  Regarded as a
fixed values if `fix.nugget = TRUE' or as a initial value for the
minimization algorithm if `fix.nugget = FALSE'. 
Defaults to zero.  
.AG fix.kappa
logical, indicating whether the extra parameter
kappa is regarded as fixed
(`fix.kappa = TRUE') or is
to be estimated (`fix.kappa = FALSE'). Defaults to
`TRUE'.  
.AG kappa
value for the extra parameter kappa.
Regarded as a fixed value if `fix.kappa = TRUE'
or as a initial value for the
minimization algorithm if `fix.kappa = FALSE'. Defaults to
0.5. This parameter is valid only if the covariance function is one
of: `"matern"', `"powered.exponential"', `"gneiting"' or
`"gneiting.matern"'.  For more details on covariance functions
see documentation for `cov.spatial'.  
.AG fix.lambda
logical, indicating whether the Box-Cox transformation parameter
lambda should be regarded as fixed
(`fix.lambda = TRUE') or is
to be estimated (`fix.lambda = FALSE'). Defaults to
`TRUE'.  
.AG lambda
value for the Box-Cox transformation parameter
lambda.
Regarded as a fixed value if `fix.lambda = TRUE'
or as a initial value for the
minimisation algorithm if `fix.lambda = FALSE'. Defaults to
1. Two particular cases are lambda = 1
indicationg no transformation, and lambda
= 0 indicating the log-transformation.  
.AG fix.psiA
logical, indicating whether the anisotropy angle parameter
psi_R should be regarded as fixed
(`fix.psiA = TRUE') or is
to be estimated (`fix.psiA = FALSE'). Defaults to
`TRUE'.  
.AG psiA
value (in radians) for the anisotropy angle parameter
psi_A. 
Regarded as a fixed value if `fix.psiA = TRUE'
or as a initial value for the
minimisation algorithm if `fix.psiA = FALSE'.
Defaults to 0. See `coords.aniso' for further
details on anisotropy correction.  
.AG fix.psiR
logical, indicating whether the anisotropy ratio parameter
psi_R should be regarded as fixed
(`fix.psiR = TRUE') or is
to be estimated (`fix.psiR = FALSE'). Defaults to
`TRUE'.  
.AG psiR
value (greater than 1) for the anisotropy ratio  parameter
psi_R. 
Regarded as a fixed value if `fix.psiR = TRUE'
or as a initial value for the
minimisation algorithm if `fix.psiR = FALSE'.
Defaults to 1. See `coords.aniso' for further
details on anisotropy correction.  
.AG cov.model
model for the correlation function. See options in the
function call and/or in the documentation for `cov.spatial'. 
.AG method
`"ML"' for maximum likelihood or `"REML"' for
restricted maximum likelihood. Defaults to `"ML"'.  
.AG components
a data-frame with fitted values for the three model
components: trend, spatial and residuals.
See the section `DETAILS' below for the model specification.
.AG nospatial
logical. If `TRUE' parameter estimates for the
model without spatial component are returned.  
.AG limits
lower and upper limits for the model parameters used in
the numerical minimisation. Uses the auxiliary function
`likfit.limits()'.  
.AG messages.screen
logical. `TRUE' indicates that
messages will be printed on the screen (or output device)
while the function is running.  
.AG \&...
additional parameters to be passed to the minimization
function. Typically `control()' type of arguments which controls the
behavior of the minimization algorithm. For further datails see documentation 
for the minimization function `nlminb'.  
.RT
An object of the `class' `"likGRF"' and `"variomodel"'.
.br
The function `summary.likGRF' is used to print a summary
of the fitted model.
.br
.IP "" 
The object is a list with the following components:
.AG cov.model
a string with the name of the correlation
function.  
.AG nugget
value of the nugget parameter tau^2.
This is an estimate if `fix.nugget = FALSE' or a fixed
value if `fix.nugget = TRUE'.  
.AG cov.pars
a vector with the estimates of the
partial sill and range parameters, respectively.
.AG kappa
value of the smoothness parameter. Valid only if 
the correlation function is one of: `"matern"',
`"powered.exponential"', `"gneiting"' or `"gneiting.matern"'
.AG beta
estimate of mean parameter beta.
Can be either a scalar or vector depending on the
trend (covariates) used in the model.  
.AG beta.var
estimated variance (or covariance matrix) for the mean
parameter beta.  
.AG lambda
Box-Cox transformation parameter. A fixed value if
`fix.lambda = TRUE' or the estimate if `fix.lambda =
      FALSE'.  
.AG aniso.pars
fixed values or estimates of the anisotropy
parameters.  
.AG method
Estimation method used, `"ML"' (maximum likelihood)
or `"REML"' (restricted maximum likelihood).
.AG loglik
the value of the maximized likelihood.  
.AG npars
number of estimated parameters.  
.AG AIC
value of the Akaike information criteria.  
.AG BIC
value of the Bayesian information criteria.  
.AG parameters.summary
a data-frame with all model parameters,
their status (estimated or fixed) and values.  
.AG info.minimisation
results returned by the minimisation function.
.AG max.dist
maximum distance between 2 data points. This
information relevant for other functions which use outputs from
`likfit'.  
.AG trend.matrix
the trend (covariates) matrix X.  
.AG log.jacobian
numerical value of the logarithm of the Jacobian of
the transformation.  
.AG nospatial
estimates for the model without the spatial
component. 
.AG call
the function call.  
.SH REFERENCES
Further information about geoR/geoS can be found at:
.br
<URL: http://www.maths.lancs.ac.uk/~ribeiro/geoR.html>
.SA
`summary.likGRF' for summary of the results,
`plot.variogram', `lines.variogram' and
`lines.variomodel' for graphical output,
`proflik' for computing profile likelihoods,
`olsfit' and `wlsfit' for other estimation metods, 
and `nlminb' for the numerical minimization function.
.EX
if(is.R()) data(s100)
ml <- likfit(s100, ini=c(0.5, 0.5), fix.nug = TRUE)
ml
summary(ml)
reml <- likfit(s100, ini=c(0.5, 0.5), fix.nug = TRUE, met = "REML")
summary(reml)
plot(variog(s100))
lines(ml)
lines(reml, lty = 2)



.KW spatial, models
.WR
