.\" -*- nroff -*- generated from .Rd format
.BG
.FN plot.geodata
.TL
Exploratory Geostatistical Plots
.DN
This function produces an 2 x 2 graphics display
with four plots: 
the first indicates spatial locations,
the second is a  3-D plot with spatial locations and associated data values
(or a histogram of the data), and the last two are plots of the data against the X and
Y coordinates.
.CS

plot.geodata(geodata, coords=geodata$coords, data = geodata$data,
     trend="cte", lambda = 1, col.data = 1, weights.divide = FALSE,
     window.new = FALSE, ...)

.RA
.AG geodata
a list containing elements `coords' and
`data' described next. Typically an object of the class
`"geodata"' - a geoR data-set. If not provided the arguments
`coords' and `data' must be provided instead.  
.AG coords
an n x 2 matrix containing in each row Euclidean
coordinates of the n data locations. By default it takes the
element `coords' of the argument `geodata'.  
.AG data
a vector with data values. By default it takes the
element `data' of the argument `geodata'.  
.AG trend
specifies the mean part of the model. The options are:
`"cte"' (constant mean - default option), `"1st"' (a first degree polynomial
on the coordinates), `"2nd"' (a second degree polynomial
on the coordinates), or a formula of the type `~X' where `X'
is a matrix with the covariates (external trend).
If provided the trend is "removed" using the function
`lm' and the residuals are plotted.  
.AG lambda
Box-Cox transformation parameter. Two particular cases
are lambda = 1 which corresponds to no
transformation and  lambda = 0 corresponding to
the log-transformation.  
.AG col.data
indicates the number of the column of the data
to be plotted. Only valid if more than one data-set is available
i.e., if the argument `data' ins a matrix.  
.AG weights.divide
if a vector of weights with the same length as
the data is provided each  data is
divided by the corresponding element in this vector.
Defaults to `NULL'.  
.AG window.new
logical. If `TRUE' a new graphic device is openned,
otherwise the current one is used. Defaults to `FALSE'.  
.AG \&...
further arguments to be passed to the function
`scatterplot3d'.  
.RT
A plot is produced on the graphics device. No values returned.
.SH REFERENCES
Further information about geoR can be found at:
.br
<URL: http://www.maths.lancs.ac.uk/~ribeiro/geoR.html>
.SA
`points.geodata', `scatterplot3d'.
.EX
if(is.R()) data(s100)
plot(s100)
.KW spatial, dplot
.WR
