.\" -*- nroff -*- generated from .Rd format
.BG
.FN plot.variogram
.TL
Plot Empirical Variogram
.DN
Plots sample (empirical) variogram from an object computed using the
function `variog'.
.CS

plot.variogram(obj, max.dist = max(obj$u), ylim = "default",
               type = "b", scaled = F, var.lines = F,
               envelope.obj = NULL, bin.cloud = F, ...)

.RA
.AG obj
an object of the class `"variogram"', typically an
output from the function `variog'.  
.AG max.dist
maximum distance in the x-axis. The default is
the maximum distance for which the sample variogram was computed.
.AG ylim
limits for the variogram values in the y-axis. The default
is from 0 to the maximum value in `obj$v'.  
.AG type
type of line for the empirical variogram. The default is
`"b"' (dots and lines).  
.AG scaled
If `TRUE' the variogram values are divided by the
sample variance. This allows comparison between variograms from
different data and/or variables.  
.AG var.lines
If `TRUE' a horizontal line is drawn at the value
of the variance of the data (if `scaled = F') or at 1 (if
`scaled = T').  
.AG envelope.obj
adds a variogram envelope previously computed by
the functions `variog.model.env' or `variog.mc.env'.
.AG bin.cloud
plots the variogram cloud if the sample variogram
from `variog' was computed with the option `option
      = "cloud"'.  
.AG \&...
other arguments to be passed to the function
`plot'.  
.RT
Produces a plot with the sample variogram on the graphics device.
.SH REFERENCES
Further information about geoR/geoS can be found at:
.br
<URL: http://www.maths.lancs.ac.uk/~ribeiro/geoR.html>
.SA
`variog' for variogram calculations,
`lines.variogram' and `lines.variomodel' for
adding lines to the current plot,
`variog.model.env' and `variog.mc.env' for
variogram envelops computation,
and `plot' for generic plot function.
.EX
sim <- grf(100, cov.pars=c(1, .2))# generates simulated data
vario <- variog(sim, max.dist=1)  # computes sample variogram
par(mfrow=c(1,2))
plot(vario)                       # the sample variogram
plot(vario, scaled=T)             # the scaled sample variogram

.KW spatial, dplot
.WR
