.\" -*- nroff -*- generated from .Rd format
.BG
.FN variog.mc.env
.TL
Envelops for Empirical Variograms Based on Permutation
.DN
This function computes emvelops for empirical variograms by
permutating the data values at the spatial locations.
.CS

variog.mc.env(geodata, coords = geodata$coords, data = geodata$data,
              obj.variog, nsim = 99, messages.screen = TRUE) 

.RA
.AG geodata
a list containing elements `coords' and
`data' as described next. 
Typically an object of the class `"geodata"' - a geoR
data-set.
If not provided the arguments
`coords' and `data' must be provided instead.  
.AG coords
an n x 2 matrix, each row containing Euclidean
coordinates of the n data locations. By default it takes the
element `$coords' of the argument `geodata'.  
.AG data
a vector with data values. By default it takes the
element `$data' of the argument `geodata'.  
.AG obj.variog
an object of the class `"variogram"', typically
an output of the function `variog'.  
.AG nsim
number of simulations to compute the envelope. Defaults to
99.  
.AG messages.screen
if `TRUE', the default, status messages
are printed while the function is running.  
.RT
An object of the `class' `"variogram.envelope"' which is a
list with the components:
.AG u
a vector with distances. 
.AG v.lower
a vector with the minimum variogram values at each
distance in `u', across the simulations.  
.AG v.upper
a vector with the maximum variogram values at each
distance in `u', across the simulations.  
.SH REFERENCES
Further information about geoR/geoS can be found at:
.br
<URL: http://www.maths.lancs.ac.uk/~ribeiro/geoR.html>
.SA
`variog.mc.env' for envelops computed by
permutating data, 
code{variog} for variogram calculations,
`plot.variogram' and `variog.mc.env' for
graphical output. The functions
`likfit',`wlsfit', `olsfit'
estimate model parameters.
.EX
if(is.R()) data(s100)
s100.vario <- variog(s100, max.dist=1)
s100.env <- variog.mc.env(s100, obj.var = s100.vario)
plot(s100.vario, envelope = s100.env)

.KW spatial, nonparametric
.WR
