.\" -*- nroff -*- generated from .Rd format
.BG
.FN variog.model.env
.TL
Envelops for Empirical Variograms Based on Model Parameters
.DN
This function computes emvelops for empirical variograms by simulating
data given the model parameters.
.CS

variog.model.env(geodata, coords = geodata$coords, obj.variog,
                 model.pars, nsim = 99, messages.screen = TRUE)

.RA
.AG geodata
a list containing element `coords'
as described next. Typically an object of the class
`"geodata"' - a geoR data-set.
If not provided the arguments
`coords' must be provided instead.  
.AG coords
an n x 2 matrix, each row containing Euclidean
coordinates of the n data locations. By default it takes the
element `$coords' of the argument `geodata'.  
.AG obj.variog
an object of the class `"variogram"', typically
an output of the function `variog'.  
.AG coords
an n x 2 matrix containing
in each row the coordinates of the n data locations.  
.AG model.pars
a list with model specification and parameter
values. The input is typically an object of the class
`variomodel' which is an output of `likfit',
`wlsfit' or `olsfit'.
This required components of list are:

.in +


.ti -\w@*\ @u
* `beta', the mean parameter. Defaults to zero.

.ti -\w@*\ @u
* `cov.model', the covariance model. Defaults to
"exponential".

.ti -\w@*\ @u
* `cov.pars', the covariance parameters
sigma^2 and phi.

.ti -\w@*\ @u
* `kappa', the extra covariance parameters for some of the
covariance models. Defaults to 0.5.

.ti -\w@*\ @u
* `nugget', the error component variance. Defaults to zero.

.ti -\w@*\ @u
* `estimator.type', the type of variogram
estimator. Options are `"classical"' or `"robust"'.
Defaults to `"classical"'.

.in -


.AG nsim
number of simulations to compute the envelope. Defaults to
99.
.AG messages.screen
if `TRUE', the default, status messages
are printed while the function is running.
.RT
An object of the `class' `"variogram.envelope"' which is a
list with the components:
.AG u
a vector with distances. 
.AG v.lower
a vector with the minimum variogram values at each
distance in `u', across the simulations.  
.AG v.upper
a vector with the maximum variogram values at each
distance in `u', across the simulations.  
.SH REFERENCES
Further information about geoR/geoS can be found at:
.br
<URL: http://www.maths.lancs.ac.uk/~ribeiro/geoR.html>
.SA
`variog.mc.env' for envelops computed by
permutating data, 
code{variog} for variogram calculations,
`plot.variogram' and `variog.mc.env' for
graphical output. The functions
`likfit',`wlsfit', `olsfit'
estimate model parameters.
.EX
if(is.R()) data(s100)
s100.ml <- likfit(s100, ini = c(0.5, 0.5), fix.nugget = TRUE)
s100.vario <- variog(s100, max.dist = 1)
s100.env <- variog.model.env(s100, obj.v = s100.vario,
   model.pars = s100.ml)
plot(s100.vario, env = s100.env)

.KW spatial
.WR
